@@ -83,6 +83,20 @@ end #end module TestPhyloXMLData
       assert_instance_of(Bio::PhyloXML::Parser,
                          phyloxml = Bio::PhyloXML::Parser.open(filename))
       common_test_next_tree(phyloxml)
+      phyloxml.close
+    end
+
+    def test_open_with_block
+      filename = TestPhyloXMLData.example_xml
+      phyloxml_bak = nil
+      ret = Bio::PhyloXML::Parser.open(filename) do |phyloxml|
+        assert_instance_of(Bio::PhyloXML::Parser, phyloxml)
+        common_test_next_tree(phyloxml)
+        phyloxml_bak = phyloxml
+        "ok"
+      end
+      assert_equal("ok", ret)
+      assert_equal(true, phyloxml_bak.closed?)
     end
 
     def test_new
@@ -192,8 +206,8 @@ end #end module TestPhyloXMLData
 
 
   class TestPhyloXML_close < Test::Unit::TestCase
-    def phyloxml_open
-      Bio::PhyloXML::Parser.open(TestPhyloXMLData.example_xml)
+    def phyloxml_open(&block)
+      Bio::PhyloXML::Parser.open(TestPhyloXMLData.example_xml, &block)
     end
     private :phyloxml_open
 
@@ -203,6 +217,25 @@ end #end module TestPhyloXMLData
       assert_nil(phyloxml.close)
     end
 
+    def test_closed?
+      phyloxml = phyloxml_open
+      assert_equal(false, phyloxml.closed?)
+      phyloxml.next_tree
+      assert_equal(false, phyloxml.closed?)
+      phyloxml.close
+      assert_equal(true, phyloxml.closed?)
+    end
+
+    def test_closed_with_block
+      ret = phyloxml_open do |phyloxml|
+        assert_equal(false, phyloxml.closed?)
+        phyloxml.next_tree
+        assert_equal(false, phyloxml.closed?)
+        phyloxml
+      end
+      assert_equal(true, ret.closed?)
+    end
+
     def test_close_after_close
       phyloxml = phyloxml_open
       phyloxml.close
@@ -215,6 +248,25 @@ end #end module TestPhyloXMLData
       assert_raise(LibXML::XML::Error) { phyloxml.next_tree }
     end
 
+    def test_next_tree_after_open_with_block
+      phyloxml = phyloxml_open { |arg| arg }
+      assert_raise(LibXML::XML::Error) { phyloxml.next_tree }
+    end
+
+    def test_close_after_open_with_block
+      phyloxml = phyloxml_open { |arg| arg }
+      assert_raise(LibXML::XML::Error) { phyloxml.close }
+    end
+
+    def test_close_in_open_with_block
+      phyloxml = phyloxml_open do |arg|
+        ret = arg
+        assert_nil(arg.close)
+        ret
+      end
+      assert_raise(LibXML::XML::Error) { phyloxml.close }
+    end
+
     def test_close_does_not_affect_io
       io = File.open(TestPhyloXMLData.example_xml)
       phyloxml = Bio::PhyloXML::Parser.for_io(io)
